rooki
=====

.. image:: https://readthedocs.org/projects/rooki/badge/?version=latest
    :target: https://rooki.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://github.com/roocs/rooki/workflows/build/badge.svg
    :target: https://github.com/roocs/rooki/actions
    :alt: Build Status

.. image:: https://img.shields.io/github/license/roocs/rooki.svg
    :target: https://github.com/roocs/rooki/blob/master/LICENSE
    :alt: GitHub license


Rooki is a client for roocs_ climate data operations service (rook_).

The rooki python package is a lightweight wrapper around the birdy_ client library for WPS.
It provides the *rooki* python object that has methods that can be called to query and invoke
the rook_ WPS.

A Jupyter Notebook is provided to demonstrate the basic use of rooki.

Full documentation_ is on ReadTheDocs.

Online Demo
-----------

You can try Rooki online using Binder (just click on the binder link below),
or view the notebooks on NBViewer.

.. image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/roocs/rooki.git/master?filepath=notebooks
   :alt: Binder Launcher

.. image:: https://raw.githubusercontent.com/jupyter/design/master/logos/Badges/nbviewer_badge.svg
   :target: https://nbviewer.jupyter.org/github/roocs/rooki/tree/master/notebooks/
   :alt: NBViewer
   :height: 20

Credits
-------

This package was created with Cookiecutter_ and the `cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _cookiecutter-pypackage: https://github.com/audreyr/cookiecutter-pypackage
.. _birdy: https://github.com/bird-house/birdy
.. _roocs: https://github.com/roocs
.. _rook: https://github.com/roocs/rook
.. _documentation: https://rooki.readthedocs.io/en/latest/
